==> wordpress-2.1.1-da_DK.tar.gz: wordpress/wp-content/themes/default/single.php <==
<?php get_header(); ?>

	<div id="content" class="widecolumn">

	<?php if (have_posts()) : while (have_posts()) : the_post(); ?>

		<div class="navigation">
			<div class="alignleft"><?php previous_post_link('&laquo; %link') ?></div>
			<div class="alignright"><?php next_post_link('%link &raquo;') ?></div>
		</div>

		<div class="post" id="post-<?php the_ID(); ?>">
			<h2><a href="<?php echo get_permalink() ?>" rel="bookmark" title="Permanent link: <?php the_title(); ?>"><?php the_title(); ?></a></h2>

			<div class="entry">
				<?php the_content('<p class="serif">L&aelig;s resten af dette indl&aelig;g &raquo;</p>'); ?>

				<?php wp_link_pages(array('before' => '<p><strong>Sider:</strong> ', 'after' => '</p>', 'next_or_number' => 'number')); ?>

				<p class="postmetadata alt">
					<small>
						Dette indl&aelig;g blev skrevet
						<?php /* Denne del er kommenteret fordi det nogle gange skal justeres lidt.
							Du skal hente dette plugin og flge instruktionerne:
							http://binarybonsai.com/archives/2004/08/17/time-since-plugin/ */
							/* $entry_datetime = abs(strtotime($post->post_date) - (60*120)); echo time_since($entry_datetime); echo ' siden'; */ ?> 
						<?php the_time('l, j. F Y') ?> kl. <?php the_time() ?>
						og er gemt i <?php the_category(', ') ?>.
						Du kan f&oslash;lge kommentarerne til indl&aelig;gget via f&oslash;lgende feed <?php comments_rss_link('RSS 2.0'); ?>.

						<?php if (('open' == $post-> comment_status) && ('open' == $post->ping_status)) {
							// Bde kommentarer og pings er bne ?>
							Du kan <a href="#respond">efterlade en kommentar</a>, eller sende <a href="<?php trackback_url(true); ?>" rel="trackback">trackback</a> fra din egen side.

						<?php } elseif (!('open' == $post-> comment_status) && ('open' == $post->ping_status)) {
							// Kun pings er bne ?>
							Der er lukket for kommentarer i &oslash;jeblikket, men du kan sende <a href="<?php trackback_url(true); ?> " rel="trackback">trackback</a> fra din egen side.

						<?php } elseif (('open' == $post-> comment_status) && !('open' == $post->ping_status)) {
							// Kommentarer er bne, men pings er lukket ?>
							Du kan springe ned til slutningen og efterlade en kommentar. Pinging er ikke tilladt i &oslash;jeblikket.

						<?php } elseif (!('open' == $post-> comment_status) && !('open' == $post->ping_status)) {
							// Hverken kommentarer eller pings er bne ?>
							B&aring;de kommentarer og pings er lukket i &oslash;jeblikket.			

						<?php } edit_post_link('Rediger dette indl&aelig;g.','',''); ?>

					</small>
				</p>

			</div>
		</div>

	<?php comments_template(); ?>

	<?php endwhile; else: ?>

		<p>Beklager, ingen indl&aelig;g matchede dine kriterier.</p>

<?php endif; ?>

	</div>

<?php get_footer(); ?>

==> wordpress-2.2.1-da_DK.tar.gz: wordpress/wp-content/themes/default/single.php <==
<?php get_header(); ?>

	<div id="content" class="widecolumn">

	<?php if (have_posts()) : while (have_posts()) : the_post(); ?>

		<div class="navigation">
			<div class="alignleft"><?php previous_post_link('&laquo; %link') ?></div>
			<div class="alignright"><?php next_post_link('%link &raquo;') ?></div>
		</div>

		<div class="post" id="post-<?php the_ID(); ?>">
			<h2><a href="<?php echo get_permalink() ?>" rel="bookmark" title="Permanent link: <?php the_title(); ?>"><?php the_title(); ?></a></h2>

			<div class="entry">
				<?php the_content('<p class="serif">L&aelig;s resten af dette indl&aelig;g &raquo;</p>'); ?>

				<?php wp_link_pages(array('before' => '<p><strong>Sider:</strong> ', 'after' => '</p>', 'next_or_number' => 'number')); ?>

				<p class="postmetadata alt">
					<small>
						Dette indl&aelig;g blev skrevet
						<?php /* Denne del er kommenteret, fordi det nogle gange skal justeres lidt.
							Du skal hente dette plugin og foelge instruktionerne:
							http://binarybonsai.com/archives/2004/08/17/time-since-plugin/ */
							/* $entry_datetime = abs(strtotime($post->post_date) - (60*120)); echo time_since($entry_datetime); echo ' siden'; */ ?>
						<?php the_time('l, j. F Y') ?> kl. <?php the_time('H:i') ?>
						og er gemt i <?php the_category(', ') ?>.
						Du kan f&oslash;lge kommentarerne til indl&aelig;gget via f&oslash;lgende feed: <?php comments_rss_link('RSS 2.0'); ?>.

						<?php if (('open' == $post-> comment_status) && ('open' == $post->ping_status)) {
							// Baade kommentarer og pings er aabne ?>
							Du kan <a href="#respond">efterlade en kommentar</a>, eller sende <a href="<?php trackback_url(true); ?>" rel="trackback">trackback</a> fra din egen side.

						<?php } elseif (!('open' == $post-> comment_status) && ('open' == $post->ping_status)) {
							// Kun pings er aabne ?>
							Der er lukket for kommentarer i &oslash;jeblikket, men du kan sende <a href="<?php trackback_url(true); ?> " rel="trackback">trackback</a> fra din egen side.

						<?php } elseif (('open' == $post-> comment_status) && !('open' == $post->ping_status)) {
							// Kommentarer er aabne, men pings er lukket ?>
							Du kan springe ned til slutningen og efterlade en kommentar. Pinging er ikke tilladt i &oslash;jeblikket.

						<?php } elseif (!('open' == $post-> comment_status) && !('open' == $post->ping_status)) {
							// Hverken kommentarer eller pings er aabne ?>
							B&aring;de kommentarer og pings er lukket i &oslash;jeblikket.			

						<?php } edit_post_link('Rediger dette indl&aelig;g.','',''); ?>

					</small>
				</p>

			</div>
		</div>

	<?php comments_template(); ?>

	<?php endwhile; else: ?>

		<p>Beklager, ingen indl&aelig;g matchede dine kriterier.</p>

<?php endif; ?>

	</div>

<?php get_footer(); ?>
